@@ -93,6 +93,16 @@ public:
      * The cursor will stop at the first column.
      */
     void cursorLeft(int n);
+    /**
+     * Moves cursor to beginning of the line by @p n lines down.
+     * The cursor will stop at the beginning of the line.
+     */
+    void cursorNextLine(int n);
+    /**
+     * Moves cursor to beginning of the line by @p n lines up.
+     * The cursor will stop at the beginning of the line.
+     */
+    void cursorPreviousLine(int n);
     /**
      * Move the cursor to the right by @p n columns.
      * The cursor will stop at the right-most column.
@@ -198,7 +208,7 @@ public:
      */
     void insertChars(int n);
     /**
-     * Repeat the preceeding graphic character @count times, including SPACE.
+     * Repeat the preceding graphic character @count times, including SPACE.
      * If @count is 0 then the character is repeated once.
      */
     void repeatChars(int count);
@@ -289,7 +299,7 @@ public:
     void setForeColor(int space, int color);
     /**
      * Sets the cursor's background color.
-     * @param space The color space used by the @p color argumnet.
+     * @param space The color space used by the @p color argument.
      * @param color The new background color.  The meaning of this depends on
      * the color @p space used.
      *
@@ -551,6 +561,8 @@ public:
     static void fillWithDefaultChar(Character* dest, int count);
 
 private:
+    Screen(const Screen &) = delete;
+    Screen &operator=(const Screen &) = delete;
 
     //copies a line of text from the screen or history into a stream using a
     //specified character decoder.  Returns the number of lines actually copied,
