@@ -4,22 +4,22 @@
 <context>
     <name>Konsole::Session</name>
     <message>
-        <location filename="../Session.cpp" line="454"/>
+        <location filename="../Session.cpp" line="448"/>
         <source>Bell in session &apos;%1&apos;</source>
-        <translation>Bell i session &apos;%1&apos;</translation>
+        <translation>Klokke i session &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../Session.cpp" line="606"/>
+        <location filename="../Session.cpp" line="600"/>
         <source>Session &apos;%1&apos; exited with code %2.</source>
-        <translation type="unfinished"></translation>
+        <translation>Session &apos;%1&apos; afsluttet med kode %2.</translation>
     </message>
     <message>
-        <location filename="../Session.cpp" line="608"/>
+        <location filename="../Session.cpp" line="602"/>
         <source>Session &apos;%1&apos; crashed.</source>
-        <translation>Session &apos;%1&apos; holdt op med at virke.</translation>
+        <translation>Session &apos;%1&apos; er holdt op med at virke.</translation>
     </message>
     <message>
-        <location filename="../Session.cpp" line="613"/>
+        <location filename="../Session.cpp" line="607"/>
         <source>Session &apos;%1&apos; exited unexpectedly.</source>
         <translation>Session &apos;%1&apos; afsluttede uventet.</translation>
     </message>
@@ -27,27 +27,27 @@
 <context>
     <name>Konsole::TerminalDisplay</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1275"/>
+        <location filename="../TerminalDisplay.cpp" line="1278"/>
         <source>Size: XXX x XXX</source>
         <translation>Størrelse: XXX x XXX</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="1287"/>
+        <location filename="../TerminalDisplay.cpp" line="1290"/>
         <source>Size: %1 x %2</source>
         <translation>Størrelse: %1 x %2</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="2787"/>
+        <location filename="../TerminalDisplay.cpp" line="2790"/>
         <source>Paste multiline text</source>
         <translation>Indsæt multilinjetekst</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="2788"/>
+        <location filename="../TerminalDisplay.cpp" line="2791"/>
         <source>Are you sure you want to paste this text?</source>
-        <translation>Er du sikker på, at du vil indsætte teksten?</translation>
+        <translation>Er du sikker på, at du vil indsætte denne tekst?</translation>
     </message>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="3258"/>
+        <location filename="../TerminalDisplay.cpp" line="3261"/>
         <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
         <translation>&lt;qt&gt;Output er blevet &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspenderet&lt;/a&gt; ved tryk på Ctrl+S. Tryk på &lt;b&gt;Ctrl+Q&lt;/b&gt; for at genoptage.&lt;/qt&gt;</translation>
     </message>
@@ -55,7 +55,7 @@
 <context>
     <name>Konsole::Vt102Emulation</name>
     <message>
-        <location filename="../Vt102Emulation.cpp" line="1121"/>
+        <location filename="../Vt102Emulation.cpp" line="1106"/>
         <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
         <translation>Ingen tastaturoversætter tilgængelig. Informationen, som er nødvendig for at konvertere tastetryk til tegn, som sendes til terminalen, mangler.</translation>
     </message>
@@ -63,7 +63,7 @@
 <context>
     <name>QMessageBox</name>
     <message>
-        <location filename="../TerminalDisplay.cpp" line="2794"/>
+        <location filename="../TerminalDisplay.cpp" line="2797"/>
         <source>Show Details...</source>
         <translation>Vis detaljer ...</translation>
     </message>
@@ -81,36 +81,36 @@
         <source>Accessible Color Scheme</source>
         <translation>Tilgængeligt farveskema</translation>
     </message>
-    <message>
-        <location filename="../Filter.cpp" line="515"/>
-        <source>Open Link</source>
-        <translation>Åbn link</translation>
-    </message>
-    <message>
-        <location filename="../Filter.cpp" line="516"/>
-        <source>Copy Link Address</source>
-        <translation>Kopiér linkadresse</translation>
-    </message>
     <message>
         <location filename="../Filter.cpp" line="520"/>
-        <source>Send Email To...</source>
-        <translation>Send e-mail til...</translation>
+        <source>Open Link</source>
+        <translation>Åben lænke</translation>
     </message>
     <message>
         <location filename="../Filter.cpp" line="521"/>
+        <source>Copy Link Address</source>
+        <translation>Kopiér lænkeadresse</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="525"/>
+        <source>Send Email To...</source>
+        <translation>Send e-post til...</translation>
+    </message>
+    <message>
+        <location filename="../Filter.cpp" line="526"/>
         <source>Copy Email Address</source>
-        <translation>Kopiér e-mailadresse</translation>
+        <translation>Kopiér e-postadresse</translation>
     </message>
 </context>
 <context>
     <name>QTermWidget</name>
     <message>
-        <location filename="../qtermwidget.cpp" line="469"/>
+        <location filename="../qtermwidget.cpp" line="465"/>
         <source>Color Scheme Error</source>
         <translation>Fejl ved farveskema</translation>
     </message>
     <message>
-        <location filename="../qtermwidget.cpp" line="470"/>
+        <location filename="../qtermwidget.cpp" line="466"/>
         <source>Cannot load color scheme: %1</source>
         <translation>Kan ikke indlæse farveskema: %1</translation>
     </message>
@@ -118,17 +118,17 @@
 <context>
     <name>SearchBar</name>
     <message>
-        <location filename="../SearchBar.cpp" line="40"/>
+        <location filename="../SearchBar.cpp" line="39"/>
         <source>Match case</source>
         <translation>Der skelnes mellem store og små bogstaver</translation>
     </message>
     <message>
-        <location filename="../SearchBar.cpp" line="46"/>
+        <location filename="../SearchBar.cpp" line="45"/>
         <source>Regular expression</source>
         <translation>Regulært udtryk</translation>
     </message>
     <message>
-        <location filename="../SearchBar.cpp" line="50"/>
+        <location filename="../SearchBar.cpp" line="49"/>
         <source>Highlight all matches</source>
         <translation>Fremhæv alle match</translation>
     </message>
